#[non_exhaustive]pub enum ShipError {
Io(Error),
Json(Error),
Http(Error),
InvalidToken,
Status(StatusCode),
Protocol(ProtocolError),
MissingStoredConfig(PathBuf),
}Expand description
Offline crash spool shipping API. Offline crash spool shipping API. Offline crash spool shipping API. Errors returned while shipping pending crash reports.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io(Error)
Filesystem operation failed.
Json(Error)
JSON metadata failed to parse or encode.
Http(Error)
HTTP client failed.
InvalidToken
Bearer token contains bytes that are not valid in an HTTP header.
Status(StatusCode)
Server rejected the upload.
Protocol(ProtocolError)
Multipart encoding failed.
MissingStoredConfig(PathBuf)
A spool entry has no usable stored upload config: sdk-config.json is
absent when required or its stored endpoint is not a valid URL.