pub struct PanicHookConfig {
pub endpoint: Url,
pub token: SecretString,
pub source: SourceId,
pub spool_dir: PathBuf,
pub kind: PanicKind,
pub build: BuildInfo,
pub context: Value,
pub context_files: Vec<PathBuf>,
pub sent_retention_days: u64,
}Expand description
Panic-hook crash capture API. Panic-hook crash capture API. Panic-hook crash capture API. Configuration for the process-wide panic hook.
Fields
endpoint: UrlHTTP endpoint for crash upload. A base server URL is joined with /v1/crashes.
token: SecretStringBearer token used by crate::ship_pending_crashes.
source: SourceIdSource identity stored in crash metadata.
spool_dir: PathBufRoot directory containing pending/ and sent/ crash entries.
kind: PanicKindCrash artifact strategy.
build: BuildInfoBuild metadata stored in crash reports.
context: ValueExtra JSON context stored in crash reports.
context_files: Vec<PathBuf>Extra files copied into each crash entry as attachments.
sent_retention_days: u64Number of days to retain successfully sent entries locally.